==> haskell-language-javascript-0.6.0.11-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-javascript.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-javascript
version: 0.6.0.11
id: language-javascript-0.6.0.11-7fF3pVqKKe2CshDfiLJOyu
key: language-javascript-0.6.0.11-7fF3pVqKKe2CshDfiLJOyu
license: BSD-3-Clause
copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
author: Alan Zimmerman
homepage: https://github.com/erikd/language-javascript
synopsis: Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.
    .
    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.
category: Language
abi: 037ad7838c26b27a9814c18469068c72
exposed: True
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.AST
    Language.JavaScript.Parser.Grammar5
    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.SrcLocation
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Process.Minify
hidden-modules: Language.JavaScript.Parser.LexerUtils
                Language.JavaScript.Parser.ParseError
                Language.JavaScript.Parser.ParserMonad
                Language.JavaScript.Parser.Token
import-dirs: /usr/lib/ghc-8.6.1/site-local/language-javascript-0.6.0.11
library-dirs: /usr/lib/ghc-8.6.1/site-local/language-javascript-0.6.0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/language-javascript-0.6.0.11
hs-libraries: HSlanguage-javascript-0.6.0.11-7fF3pVqKKe2CshDfiLJOyu
depends:
    array-0.5.2.0 base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 mtl-2.2.2 text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
haddock-html: /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-javascript-0.6.0.11-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-javascript.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-javascript
version: 0.6.0.11
id: language-javascript-0.6.0.11-EORWeExf4JA8bwgXEwH8U1
key: language-javascript-0.6.0.11-EORWeExf4JA8bwgXEwH8U1
license: BSD-3-Clause
copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
author: Alan Zimmerman
homepage: https://github.com/erikd/language-javascript
synopsis: Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.
    .
    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.
category: Language
abi: 186d3d8066b8801d18051af92a0ae1b9
exposed: True
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.AST
    Language.JavaScript.Parser.Grammar5
    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.SrcLocation
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Process.Minify
hidden-modules: Language.JavaScript.Parser.LexerUtils
                Language.JavaScript.Parser.ParseError
                Language.JavaScript.Parser.ParserMonad
                Language.JavaScript.Parser.Token
import-dirs: /usr/lib/ghc-8.6.3/site-local/language-javascript-0.6.0.11
library-dirs: /usr/lib/ghc-8.6.3/site-local/language-javascript-0.6.0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/language-javascript-0.6.0.11
hs-libraries: HSlanguage-javascript-0.6.0.11-EORWeExf4JA8bwgXEwH8U1
depends:
    array-0.5.3.0 base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 mtl-2.2.2 text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
haddock-html: /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
